==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ResponsiveStateEnteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescription } from "./ResponsiveStateEnteringEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateEnteringEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ResponsiveStateEnteringEventArgsDescriptionMetadata, _super);
    function ResponsiveStateEnteringEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateEnteringEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateEnteringEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateEnteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateEnteringEventArgsDescriptionMetadata.c(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
        if (a.g(ResponsiveStateEnteringEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateEnteringEventArgsDescriptionMetadata.b(a);
        a.u("ResponsiveStateEnteringEventArgs", function () { return new ResponsiveStateEnteringEventArgsDescription(); });
        a.t("ResponsiveStateEnteringEventArgs", ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.$t = markType(ResponsiveStateEnteringEventArgsDescriptionMetadata, 'ResponsiveStateEnteringEventArgsDescriptionMetadata');
    ResponsiveStateEnteringEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteringEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateEnteringEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ResponsiveStateEnteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescription } from "./ResponsiveStateEnteringEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateEnteringEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ResponsiveStateEnteringEventArgsDescriptionMetadata, _super);
    function ResponsiveStateEnteringEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateEnteringEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateEnteringEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateEnteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateEnteringEventArgsDescriptionMetadata.c(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
        if (a.j(ResponsiveStateEnteringEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateEnteringEventArgsDescriptionMetadata.b(a);
        a.aa("ResponsiveStateEnteringEventArgs", function () { return new ResponsiveStateEnteringEventArgsDescription(); });
        a.z("ResponsiveStateEnteringEventArgs", ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.$t = markType(ResponsiveStateEnteringEventArgsDescriptionMetadata, 'ResponsiveStateEnteringEventArgsDescriptionMetadata');
    ResponsiveStateEnteringEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteringEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateEnteringEventArgsDescriptionMetadata };
